Merge pull request #264 from pzins/missing_end_marker

Fix missing MARKER_END

[ROCm/clr commit: a1e0c96689]
Tento commit je obsažen v:
Ben Sander
2017-11-20 06:08:01 -06:00
odevzdal GitHub
3 změnil soubory, kde provedl 7 přidání a 2 odebrání
+3
Zobrazit soubor
@@ -92,5 +92,8 @@ namespace hip_impl
delete static_cast<L*>(locked_stream);
locked_stream = nullptr;
if(HIP_PROFILE_API) {
MARKER_END();
}
}
}
+1 -1
Zobrazit soubor
@@ -269,7 +269,7 @@ hipError_t hipCtxGetSharedMemConfig ( hipSharedMemConfig * pConfig )
hipError_t hipCtxSynchronize ( void )
{
HIP_INIT_API(1);
return ihipSynchronize(); //TODP Shall check validity of ctx?
return ihipLogStatus(ihipSynchronize()); //TODP Shall check validity of ctx?
}
hipError_t hipCtxGetFlags ( unsigned int* flags )
+3 -1
Zobrazit soubor
@@ -1592,7 +1592,9 @@ void ihipPostLaunchKernel(const char *kernelName, hipStream_t stream, grid_launc
tprintf(DB_SYNC, "ihipPostLaunchKernel, unlocking stream\n");
stream->lockclose_postKernelCommand(kernelName, lp.av);
MARKER_END();
if(HIP_PROFILE_API) {
MARKER_END();
}
}
//=================================================================================================